# gurke

A Python3 only `gherkin` implementation with type hints.

## Introduction

TODO: comming soon...

## Installation

```console
pip install gurke
```

## License

`gurke` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.

## Third Party Notice

`gurke` contains parts of the original [`gherkin`](https://github.com/cucumber/gherkin) implementation
